[![Enterprise Modules](https://raw.githubusercontent.com/enterprisemodules/public_images/master/banner1.jpg)](https://www.enterprisemodules.com)

#### Table of Contents

- [Overview](#overview)
- [License](#license)
- [Description](#description)
- [Setup](#setup)
  - [Requirements](#requirements)
  - [Installing the pg_secured module](#installing-the-pg_secured-module)
- [Usage](#usage)
  - [Enabling CIS for your database](#enabling-cis-for-your-database)
    - [Easy to customize values](#easy-to-customize-values)
    - [Correlate Puppet changes to CIS](#correlate-puppet-changes-to-cis)
  - [Upgrade to a new CIS or Postgres version](#upgrade-to-a-new-cis-or-postgres-version)
- [Reference](#reference)
- [Limitations](#limitations)

## Overview

The `pg_secured` module is the Puppet implementation of multiple security-related controls. At this point in time we support:

- [Center for Internet Security (CIS) benchmarks](https://www.cisecurity.org/)
- [DoD Security Technical Implementation Guides](https://public.cyber.mil/stigs/)


We now support the current versions:

- [CIS Postgres 14 V1.0.0](https://www.enterprisemodules.com/docs/pg_secured/cis/pg14_V1.0.0.html)
- [CIS Postgres 13 V1.0.0](https://www.enterprisemodules.com/docs/pg_secured/cis/pg13_V1.0.0.html)
- [CIS Postgres 12 V1.0.0](https://www.enterprisemodules.com/docs/pg_secured/cis/pg12_V1.0.0.html)
- [CIS Postgres 11 V1.0.0](https://www.enterprisemodules.com/docs/pg_secured/cis/pg11_V1.0.0.html)
- [CIS Postgres 10 V1.0.0](https://www.enterprisemodules.com/docs/pg_secured/cis/pg10_V1.0.0.html)

We are currently working on:

- STIG PostgreSQL 9.x Security Technical Implementation Guide

The module is part of our family of Puppet modules to manage and secure Postgres databases with Puppet. Besides the [`pg_secured`](https://www.enterprisemodules.com/shop/products/puppet-pg_secured-module) module, this family also contains:

- [pg_config](https://www.enterprisemodules.com/shop/products/puppet-pg_config-module) For configuring every aspect of your Postgres database
- [pg_profile](https://forge.puppet.com/modules/enterprisemodules/pg_config) As an easy customizable profile class to manage your complete progress setup.

## License

This is an affordable commercially licensed module. But you can use the module on VirtualBox based development systems for **FREE**. When used on **real** systems a license is required.

You can license our modules in multiple ways. Our basic licensing model requires a subscription per node. But [contact](https://www.enterprisemodules.com/company/contact/) us for details.

Check the [License](https://forge.puppet.com/enterprisemodules/pg_secured/license) for details.

## Description

Let's first dive into the question: "What configuration settings are needed to get my system secure?". Many people have asked themselves this question. The [Center for Internet Security (CIS)](https://www.cisecurity.org/) is one of the means to get an answer.  CIS also has a security baseline for Postgres 12: [CIS Postgres Database Server 12c Benchmark v2.0.0](https://www.cisecurity.org/benchmark/postgresql/). We have taken this baseline and Puppetized it for you to use. 

It is called the pg_secured and contains an implementation of all rules in the benchmark that describe a configuration setting inside of the database. At this point 124 of the 129 rules are implemented and 5 are not because they rely on settings outside of the database.

On a Puppet run, the module will inspect all settings described in the CIS rules and apply changes to them if they deviate from the standard. (If you have started the Puppet run with a noop, it will do nothing but report all changes that would have been made. ). All changes will be reported to the Puppet master and on the console, you get an overview of the changes. Because the Puppet agent runs every 20 minutes (or different if you set it to a different interval) every 20 minutes your database configuration is checked against the CIS benchmark and you can sleep well and be assured your data is safe.

Check [the documentation here](https://www.enterprisemodules.com/docs/pg_secured/description.html)

## Setup

### Requirements

The [`pg_secured`](https://www.enterprisemodules.com/shop/products/puppet-pg_secured-module) module requires:

- Puppet module [`enterprisemodules-easy_type`](https://forge.puppet.com/enterprisemodules/easy_type) installed.
- Puppet version 4.0 or higher. Can be Puppet Enterprise or Puppet Open Source
- Postgres 12 or higher
- A valid Postgres license
- A valid Enterprise Modules license for usage.
- Runs on most Linux systems.
- Runs on Solaris

### Installing the pg_secured module

To install these modules, you can use a `Puppetfile`

```
mod 'enterprisemodules/pg_secured'               ,'3.x.x'
```

Then use the `librarian-puppet` or `r10K` to install the software.

You can also install the software using the `puppet module`  command:

```
puppet module install enterprisemodules-pg_secured
```

## Usage

The scope of securing your Postgres database is large. The number of security controls in the CIS benchmark is large. This might make you think that it is difficult to get started, but actually, it is very simple. 

### Enabling CIS for your database

Securing your database with the `pg_secured` module is as easy as adding one line of puppet code to your manifest. In its most basic form:

"`puppet
pg_secured::ensure_cis {'MYDB':}
```
is enough.

#### Easy to skip controls

The CIS benchmark and STIG documents are very extensive. Applying *ALL* controls can make your database too secure for your application. The `pg_secured` module allows you to specify what controls you want to skip. You can, for examle use the parameter `skip_list`

```puppet
pg_secured::ensure_cis {'MYDB':
  skip_list   => [
    'log_file_destination_directory_is_set_correctly',
    'filename_pattern_for_log_files_is_set_correctly',
```

You can also use hiera to skip certain controls. Here is an example of that:

```yaml
pg_secured::controls::log_file_destination_directory_is_set_correctly::mydb: skip
pg_secured::controls::filename_pattern_for_log_files_is_set_correctly::mydb: skip
```

#### Easy to customize values

For specific controls, the CIS benchmark allows you to specify a value. To be compiant with the CIS benchmark, the specified value must be within a specific range. The `pg_secured` module supports this. Let's look at an example. The control `failed_login_attempts_is_less_than_or_equal_to_5` guards that the number of failed login attempts is 5 or less (as the name states). The default value the `pg_secured` module enforces is `5`. But you can make it less. You can use the value `3`.

```yaml
pg_secured::controls::failed_login_attempts_is_less_than_or_equal_to_5::preferred_value:  3
```

Is a way to do this. To ensure you stay compliant, the `pg_secured` module enforces that the values stay within the bounds of CIS range. When you specify a value that is outside of the range, Puppet will not accept it. Here is an example when we specify `6`:

```
Error: Evaluation Error: Error while evaluating a Resource Statement, Pg_secured::Controls::Failed_login_attempts_is_less_than_or_equal_to_5[TEST]: parameter 'preferred_value' expects an Integer[0, 5] value, got Integer[6, 6] (file: /root/examples/apply_one_control.pp, line: 5) on node pg_secured
```


#### Correlate Puppet changes to CIS

Although it is excellent that Puppet guards the compliance of your database, it is good to know that when Puppet changes something, WHY it changed something. What was the control that caused this? And preferably, what paragraph in what version of the CIS benchmark states this.

The `pg_secured` module helps you with this. Here is some example output:

```
Notice: /Stage[main]/Pg13::V1_0_0::P5_1_1_1::Test/pg_secured::Controls::Execute_is_revoked_from_public_on_network_packages[TEST]/pg_secured::Internal::Revoke_public_grants[DBMS_LDAP@TEST]/Ora_object_grant[PUBLIC->SYS.DBMS_LDAP@TEST]/permissions: revoked the EXECUTE right(s)
Notice: /Stage[main]/Pg13::V1_0_0::P6_1_1::Test/pg_secured::Controls::User_audit_option_is_enabled[TEST]/pg_secured::Internal::Audit_option[USER@TEST]/Ora_statement_audit[USER@TEST]/ensure: created
Notice: /Stage[main]/Pg13::V1_0_0::P6_1_2::Test/pg_secured::Controls::Role_audit_option_is_enabled[TEST]/pg_secured::Internal::Audit_option[ROLE@TEST]/Ora_statement_audit[ROLE@TEST]/ensure: created
Notice: /Stage[main]/Pg13::V1_0_0::P3_1::Test/pg_secured::Controls::Failed_login_attempts_is_less_than_or_equal_to_5[TEST]/pg_secured::Internal::Profile_setting[failed_login_attempts@TEST]/Ora_profile[DEFAULT@TEST]/failed_login_attempts: failed_login_attempts changed 10 to 5
Notice: /Stage[main]/Pg13::V1_0_0::P6_2_1::Test/pg_secured::Controls::Create_user_action_audit_is_enabled[TEST]/pg_secured::Internal::Audit_policy[actions@TEST@create_user]/Ora_audit_
```
As you can see all of the messages contain:
The database version of the CIS benchmark (e.g. `/Pg13`)
The document version of the CIS benchmark (e.g. `::V1_0_0`)
The paragraph in the  CIS benchmark (e.g. `::P6_2_1`)
The database that is changed (e.g. "::Test`)
The name of the control (e.g. `create_user_action_audit_is_enabled`)
This way, you can always see what the reason is for a change.

### Upgrade to a new CIS or Postgres version

Because the exclusion lists, preferred values, and skip lists, are bound to the name of the control, your customizations will most of the times be compatible with newer versions of a CIS benchmark. So when a more recent version comes. You only have to change the `doc_version` property. Let's see an example. Let's say a V1.1.0 for the `pg13` is available.

```puppet
pg_secured::ensure_cis {'MYDB':
  product_version => 'pg14',
  doc_version     => 'V1.1.0'
}
```

This is enough to start using the new CIS version. Sometimes CIS. Of course, you will still have to look if new controls are available that you want to skip or customize. Also, sometimes the value of a configuration item changes. This will cause a new control in the `pg_secured` module. Let's look at this in a contrived example.

Let's say that in the CIS document, the setting for the number of failed login attempts has been changed from a value of `5` or less to a value of `3` or less. The original control was named: `failed_login_attempts_is_less_than_or_equal_to_5`. It will still be available. But a new control is also available. It is now called `failed_login_attempts_is_less_than_or_equal_to_3`. Just change these values in your skip_lists, excludes and preferred value settings is enough.


## Reference

Here you can find some more information regarding this puppet module:

- [The `pg_secured` documentation](https://www.enterprisemodules.com/docs/pg_secured/description.html)


## Limitations

This module runs on most Linux versions. It requires a puppet version 5 or higher. The module does **NOT** run on windows systems.
