#
# See the file "LICENSE" for the full license governing this code.
#
# This function determins the CIS default doc_version based on the product_version.It uses the following algorithmn:
# 
# 1. Use the specified version for this database
# 2. Use a generic specified version for all databases
# 3. Use the latest version available for thos product_version
#
Puppet::Functions.create_function('pg_secured::default_doc_version') do
    dispatch :default_doc_version do
      param 'Optional[String[1]]', :product_version
      param "Enum['cis','stig']",   :type
    end
  
    def default_doc_version(product_version, type)
      #
      # When a version is specified, use it.
      #
      value = lookup_setting('doc_version', nil)
      return value if value
      return nil if product_version.nil?
      #
      # The array of versions is sorted from newest on top down to the latest. So the first one
      # in the array is the lastest and we need that one.
      #
      valid_combinations(type)[product_version].first
    end
  
    def lookup_setting(sid, default_value)
      call_function('pg_secured::lookup_setting', sid, default_value )
    end
  
    def valid_combinations(type)
      @valid_combinations ||= call_function('lookup', "pg_secured::#{type}::valid_combinations", data_type('Hash'), 'first', nil)
    end
  
    def data_type(string)
      parser = Puppet::Pops::Types::TypeParser.singleton
      parser.parse(string)
    end

  end
    