#
# pg_secured::controls::backup_and_restore_tool_pgbackrest_is_installed_and_configured
#
# @summary pgBackRest aims to be a simple, reliable backup and restore system that can seamlessly scale up to the largest databases and workloads.
# Instead of relying on traditional backup tools like tar and rsync, pgBackRest implements all backup features internally and uses a custom protocol for communicating with remote systems. Removing reliance on tar and rsync allows for better solutions to database-specific backup challenges. The custom remote protocol allows for more flexibility and limits the types of connections that are required to perform a backup which increases security.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::backup_and_restore_tool_pgbackrest_is_installed_and_configured: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::backup_and_restore_tool_pgbackrest_is_installed_and_configured::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `backup_and_restore_tool_pgbackrest_is_installed_and_configured` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 8.3
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 8.3
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::backup_and_restore_tool_pgbackrest_is_installed_and_configured {
  pg_secured_setup { "backup_and_restore_tool_pgbackrest_is_installed_and_configured on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
