#
# pg_secured::controls::debug_pretty_print_is_enabled
#
# @summary Enabling debug_pretty_print indents the messages produced by debug_print_parse,
# debug_print_rewritten, or debug_print_plan making them significantly easier to
# read.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::debug_pretty_print_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::debug_pretty_print_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `debug_pretty_print_is_enabled` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.17
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.17
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.17
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.17
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.19
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::debug_pretty_print_is_enabled {
  pg_secured_setup { "debug_pretty_print_is_enabled on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "debug_pretty_print@${title}":
    value => 'on',
  }
}
