#
# pg_secured::controls::debug_print_plan_is_disabled
#
# @summary The debug_print_plan setting enables printing the execution plan for each executed query.
# These messages are emitted at the LOG message level. Unless directed otherwise by your organization's logging policy, it is recommended this setting be disabled by setting it to off.
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::debug_print_plan_is_disabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::debug_print_plan_is_disabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `debug_print_plan_is_disabled` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.16
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.16
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.16
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.16
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.18
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::debug_print_plan_is_disabled {
  pg_secured_setup { "debug_print_plan_is_disabled on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "debug_print_plan@${title}":
    value => 'off',
  }
}
