#
# pg_secured::controls::excessive_dml_privileges_are_revoked
#
# @summary DML (insert, update, delete) operations at the table level should be restricted
# to only authorized users. PostgreSQL manages table level DML permissions via the
# GRANT statement.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::excessive_dml_privileges_are_revoked: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::excessive_dml_privileges_are_revoked::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `excessive_dml_privileges_are_revoked` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 4.4
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 4.4
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 4.4
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::excessive_dml_privileges_are_revoked {
  pg_secured_setup { "excessive_dml_privileges_are_revoked on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
