#
# pg_secured::controls::fips_140_2_openssl_cryptography_is_used
#
# @summary Install, configure, and use OpenSSL on a platform that has a NIST certified FIPS
# 140-2 installation of OpenSSL. This provides PostgreSQL instances the ability to
# generate and validate cryptographic hashes to protect unclassified information
# requiring confidentiality and cryptographic protection, in accordance with the
# data owner's requirements.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::fips_140_2_openssl_cryptography_is_used: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::fips_140_2_openssl_cryptography_is_used::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `fips_140_2_openssl_cryptography_is_used` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 6.7
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 6.7
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 6.7
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 6.7
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 6.7
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::fips_140_2_openssl_cryptography_is_used {
  pg_secured_setup { "fips_140_2_openssl_cryptography_is_used on ${title}":
    ensure => 'present',
  }

  alert('Specified CIS control is not yet automatically enforced.')
}
