#
# pg_secured::controls::log_file_destination_directory_is_set_correctly
#
# @summary The log_directory setting specifies the destination directory for log files when
# log_destination is stderr or csvlog. It can be specified as relative to the
# cluster data directory ($PGDATA) or as an absolute path. log_directory should be
# set according to your organization's logging policy.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::log_file_destination_directory_is_set_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::log_file_destination_directory_is_set_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `log_file_destination_directory_is_set_correctly` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.4
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.4
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.4
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.4
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.4
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::log_file_destination_directory_is_set_correctly {
  pg_secured_setup { "log_file_destination_directory_is_set_correctly on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "log_directory@${title}":
    value => '/var/log/postgres',
  }
}
