#
# pg_secured::controls::maximum_log_file_size_is_set_correctly
#
# @summary The log_rotation_size setting determines the maximum size of an individual log
# file. Once the maximum size is reached, automatic log file rotation will occur.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::maximum_log_file_size_is_set_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::maximum_log_file_size_is_set_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `maximum_log_file_size_is_set_correctly` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.9
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.9
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.9
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.9
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.9
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::maximum_log_file_size_is_set_correctly {
  pg_secured_setup { "maximum_log_file_size_is_set_correctly on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "log_rotation_size@${title}":
    value => 1048576 # is '1GB'
  }
}
