#
# pg_secured::controls::postgresql_pg_wheel_group_membership_is_correct
#
# @summary 
# The group pg_wheel is explicitly created on a host where the PostgreSQL serveris installed. Membership in this group enables an ordinary user account to gain'superuser' access to a database cluster by using the sudo command (See 'Ensuresudo is configured correctly' later in this benchmark). Only user accountsauthorized to have superuser access should be members of the pg_wheel group.## SkippingTo deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provideyou with three ways:1) Add `pg_secured::controls::postgresql_pg_wheel_group_membership_is_correct: skip` to your hiera data. This will skip this control for **ALL** databases.  2) Add `pg_secured::controls::postgresql_pg_wheel_group_membership_is_correct::dbname: skip` to your hiera data. This will skip this control for specified database only.  3) Add an entry with the content `postgresql_pg_wheel_group_membership_is_correct` to the array value `pg_secured::skip_list` in your hiera data.  ## BenchmarksThis control is used in the following benchmarks:- [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 2.2- [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 2.2- [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 2.2- [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 2.2
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::postgresql_pg_wheel_group_membership_is_correct (
  Integer          $gid              = pg_secured::lookup_setting('gid', 1001),
  Array[String[1]] $authorized_users = pg_secured::lookup_setting('authorized_users', ['postgres']),
) {
  pg_secured_setup { "postgresql_pg_wheel_group_membership_is_correct on ${title}":
    ensure => 'present',
  }

  resource_value { 'Group[pg_wheel]members':
    value        => $authorized_users,
    allow_create => true,
    require      => [
      Pg_secured_setup["postgresql_pg_wheel_group_membership_is_correct on ${title}"],
    ],
  }
}
