#
# pg_secured::ensure_pg_permissions_libraries
#
# @summary Make sure all required packages and libraries are loaded for the permissions extension.
#
#
# @param title
#    The name of the database.
#
# @param title
#    The name of the database.
#
# @param [String[1]] release
#    The release of postgres.
#
# @param [Array[String[1]]] required_packages
#    The packages needed before we can install the extension.
#
# @param [String[1]] url
#    URL where to fetch the extension.
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
class pg_secured::ensure_pg_permissions_libraries (
  String[1]        $release,
  Array[String[1]] $required_packages,
  String[1]        $url
) {
  $release_name = "REL_${release}"

  contain epel
  if $facts['pg_major_version'] != undef {
    $required_packages.each |$package| {
      unless defined(Package[$package]) {
        package { $package:
          ensure  => 'present',
          require => Class['epel'],
          before  => Archive["/tmp/pg_permissions/${release_name}.tar.gz"],
        }
      }
    }

    archive { "/tmp/pg_permissions/${release_name}.tar.gz":
      ensure       => present,
      extract      => true,
      extract_path => '/tmp',
      source       => $url,
      creates      => "/tmp/pg_permissions-${release_name}/",
      cleanup      => true,
    }

    -> exec { 'Build pg_permission extension':
      cwd         => "/tmp/pg_permissions-${release_name}/",
      environment => ["PATH=/usr/pgsql-${facts['pg_major_version']}/bin:\$PATH"],
      command     => '/usr/bin/make install',
    }

    -> exec { 'Cleanup /tmp/pg_permissions':
      command => '/bin/rm -rf /tmp/pg_permissions/',
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
