#
# See the file "LICENSE" for the full license governing this code.
#
#++--++
#
# pg_secured::ensure_set_user_libraries
#
# Make sure all required packes and libraries are loaded for the permissions extension
#
#--++--
#
class pg_secured::ensure_set_user_libraries (
  String[1]        $release,
  Array[String[1]] $required_packages,
  String[1]        $url
) {
  $release_name = "REL${release}"

  contain epel
  if $facts['pg_major_version'] != undef {
    $required_packages.each |$package| {
      unless defined(Package[$package]) {
        package { $package:
          ensure  => 'present',
          require => Class['epel'],
        }
      }
    }

    archive { "/tmp/set_user/${release_name}.tar.gz":
      ensure       => present,
      extract      => true,
      extract_path => '/tmp',
      source       => $url,
      creates      => "/tmp/set_user-${release_name}/",
      cleanup      => true,
    }

    -> exec { 'Build set_user extension':
      cwd         => "/tmp/set_user-${release_name}/",
      environment => ["PATH=/usr/pgsql-${facts['pg_major_version']}/bin:/usr/bin:\$PATH"],
      command     => '/usr/bin/make USE_PGXS=1 install',
      require     => Package[$required_packages],
    }

    -> exec { 'Cleanup /tmp/set_user':
      command => '/bin/rm -rf /tmp/set_user/',
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
